@@ -1,12 +1,13 @@
 package Plack::App::ServiceStatus::DBIC;
+
+# ABSTRACT: Check DBIC connection
+
+our $VERSION = '0.904'; # VERSION
+
 use 5.018;
 use strict;
 use warnings;
 
-our $VERSION = '0.900';
-
-# ABSTRACT: Check DBIC connection
-
 sub check {
     my ( $class, $args ) = @_;
     $args = [$args] unless ref($args) eq 'ARRAY';
@@ -34,7 +35,7 @@ Plack::App::ServiceStatus::DBIC - Check DBIC connection
 
 =head1 VERSION
 
-version 0.903
+version 0.904
 
 =head1 SYNOPSIS
 
@@ -65,11 +66,11 @@ You can pass another query when loading C<Plack::App::ServiceStatus>:
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Thomas Klausner.
+This software is copyright (c) 2016 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
