@@ -1,14 +1,15 @@
 package Plack::App::ServiceStatus::NetStomp;
+
+# ABSTRACT: Check Net::Stomp connection
+
+our $VERSION = '0.904'; # VERSION
+
 use 5.018;
 use strict;
 use warnings;
 use Module::Runtime qw(require_module);
 use Try::Tiny;
 
-our $VERSION = '0.900';
-
-# ABSTRACT: Check Net::Stomp connection
-
 sub check {
     my ( $class, $stomp ) = @_;
 
@@ -59,7 +60,7 @@ Plack::App::ServiceStatus::NetStomp - Check Net::Stomp connection
 
 =head1 VERSION
 
-version 0.903
+version 0.904
 
 =head1 SYNOPSIS
 
@@ -85,11 +86,11 @@ or a code reference which returns such a L<Net::Stomp> instance when called.
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Thomas Klausner.
+This software is copyright (c) 2016 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
